import React from 'react';
export interface IInputProps extends React.ComponentPropsWithoutRef<'input'> {
    /**
     * Defines the color of the input
     */
    valid?: boolean;
    /**
     * Defines if the input is disabled
     */
    disabled?: boolean;
    /**
     * Defines if onWheel event should be enabled on type `number`.
     * By default Input component has disabled the onWheel event to
     * prevent value change on scroll from the input type number.
     */
    enableWheelEventOnNumber?: boolean;
    /**
     * Defines the type of the input
     */
    type?: string;
    /**
     * Defines left side area of the input
     */
    left?: () => React.ReactNode;
    /**
     * Defines the appearance for left side area of the input
     */
    lClass?: string;
    /**
     * Defines left side container appearance
     */
    lContainerClass?: string;
    /**
     * Defines right side area of the input
     */
    right?: () => React.ReactNode;
    /**
     * Defines the appearance for right side area of the input
     */
    rClass?: string;
    /**
     * Defines right side contianer appearance
     */
    rContainerClass?: string;
    /**
     * Defines contianer appearance
     */
    containerClass?: string;
}
export declare const inputStyles: Record<string, string>;
declare const Input: React.ForwardRefExoticComponent<IInputProps & React.RefAttributes<HTMLInputElement>>;
export default Input;
//# sourceMappingURL=Input.d.ts.map